@@ -17,7 +17,7 @@ our @EXPORT_OK = qw(
     );
 our @EXPORT = @EXPORT_OK;
 
-our $VERSION=q{3.1.12};
+our $VERSION=q{3.1.13};
 
 our @MANIFEST = (
 'clear.sh',
@@ -634,6 +634,15 @@ my %parse_options_replication = (
                                             '(default: '. $MySQL::Sandbox::default_users{'repl_user'} . ')'
                                          ] 
                             },
+    master_ip           => {
+                                value => '127.0.0.1',
+                                parse => 'master_ip=s',
+                                so    => 95,
+                                help  => [
+                                            'Which IP is used by slaves to connect to the master',
+                                            '(default: 127.0.0.1)'
+                                         ]
+                            },
 
     repl_password           => {
                                 value => $MySQL::Sandbox::default_users{'repl_password'},
